@@ -43,12 +43,11 @@ defaultsCfg.set('USER_CONFIG_DEFAULTS', 'sbatch_time', '0-04:00')
 defaultsCfg.set('USER_CONFIG_DEFAULTS', 'sbatch_memPerCPU', '2048')
 defaultsCfg.set('USER_CONFIG_DEFAULTS', 'scratchDir', '${LOCALSCRATCH}')
 defaultsCfg.add_section('USER_CONFIG_VALID_VALUES')
-defaultsCfg.set('USER_CONFIG_VALID_VALUES', 'sbatch_partition', 'Def,cp3,cp3-fast,cp3-gpu')
-defaultsCfg.set('USER_CONFIG_VALID_VALUES', 'sbatch_qos', 'normal,cp3,cp3-gpu')
+defaultsCfg.set('USER_CONFIG_VALID_VALUES', 'sbatch_partition', 'Def,cp3')
+defaultsCfg.set('USER_CONFIG_VALID_VALUES', 'sbatch_qos', 'normal,cp3')
 defaultsCfg.set('USER_CONFIG_VALID_VALUES', 'environmentType', 'cms')
 defaultsCfg.add_section('USER_CONFIG_PARTITIONS_FOR_QOS')
-defaultsCfg.set('USER_CONFIG_PARTITIONS_FOR_QOS', 'qos_cp3', 'cp3,cp3-fast')
-defaultsCfg.set('USER_CONFIG_PARTITIONS_FOR_QOS', 'qos_cp3-gpu', 'cp3-gpu')
+defaultsCfg.set('USER_CONFIG_PARTITIONS_FOR_QOS', 'qos_cp3', 'cp3')
 defaultsCfg.set('USER_CONFIG_PARTITIONS_FOR_QOS', 'alternative_qos', 'normal')
 xdgConfigDirsDef = os.path.join(os.path.sep, 'etc', 'xdg')
 xdgConfigDirs = os.getenv('XDG_CONFIG_DIRS', xdgConfigDirsDef)
